==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/outputs/ActionIpCommunityPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.outputs

import kotlin.Suppress

/**
 * IP Community Properties.
 * @property add IP Community ID list properties.
 * @property delete IP Community ID list properties.
 * @property set IP Community ID list properties.
 */
public data class ActionIpCommunityPropertiesResponse(
    public val add: IpCommunityIdListResponse? = null,
    public val delete: IpCommunityIdListResponse? = null,
    public val `set`: IpCommunityIdListResponse? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.managednetworkfabric.outputs.ActionIpCommunityPropertiesResponse):
            ActionIpCommunityPropertiesResponse = ActionIpCommunityPropertiesResponse(
            add = javaType.add().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            delete = javaType.delete().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            `set` = javaType.`set`().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/outputs/ActionIpCommunityPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.outputs

import kotlin.Suppress

/**
 * IP Community Properties.
 * @property add IP Community ID list properties.
 * @property delete IP Community ID list properties.
 * @property set IP Community ID list properties.
 */
public data class ActionIpCommunityPropertiesResponse(
    public val add: IpCommunityIdListResponse? = null,
    public val delete: IpCommunityIdListResponse? = null,
    public val `set`: IpCommunityIdListResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.managednetworkfabric.outputs.ActionIpCommunityPropertiesResponse): ActionIpCommunityPropertiesResponse = ActionIpCommunityPropertiesResponse(
            add = javaType.add().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            delete = javaType.delete().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            `set` = javaType.`set`().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
